pub enum CreateEndUserEvmSwapRuleAction {
Reject,
Accept,
}Expand description
Whether matching the rule will cause the request to be rejected or accepted.
JSON schema
{
"description": "Whether matching the rule will cause the request to be rejected or accepted.",
"examples": [
"accept"
],
"type": "string",
"enum": [
"reject",
"accept"
]
}Variants