pub enum SignEndUserEvmHashRuleAction {
Reject,
Accept,
}Expand description
Whether any attempts to sign a hash will be accepted or rejected. This rule does not accept any criteria.
JSON schema
{
"description": "Whether any attempts to sign a hash will be accepted or rejected. This rule does not accept any criteria.",
"examples": [
"accept"
],
"type": "string",
"enum": [
"reject",
"accept"
]
}Variants