pub enum TransferRequestAmountType {
Target,
Source,
}Expand description
Specifies whether the given amount is to be received by the target or taken from the source.
- `target`: The transfer `target` receives the exact value specified in `amount`. Fees are added to the amount taken from the transfer `source`.
- `source`: The transfer `target` receives the value specified in `amount`, minus any fees.JSON schema
{
"description": "Specifies whether the given amount is to be received by the target or taken from the source.\n\n- `target`: The transfer `target` receives the exact value specified in `amount`. Fees are added to the amount taken from the transfer `source`.\n- `source`: The transfer `target` receives the value specified in `amount`, minus any fees.\n",
"default": "source",
"examples": [
"source"
],
"type": "string",
"enum": [
"target",
"source"
]
}Variants