pub enum X402BatchSettlementSettlePayloadType {
Settle,
}Expand description
The payload-type discriminator. Must be "settle" for a server-to-facilitator request to move claimed funds to the receiver.
JSON schema
{
"description": "The payload-type discriminator. Must be `\"settle\"` for a server-to-facilitator request to move claimed funds to the receiver.",
"type": "string",
"enum": [
"settle"
]
}Variants
Settle