pub enum X402SearchResourcesResponseSearchMethod {
Text,
Vector,
Hybrid,
}Expand description
The search method used to retrieve the results (e.g., “text”, “vector”, “hybrid”).
JSON schema
{
"description": "The search method used to retrieve the results (e.g., \"text\", \"vector\", \"hybrid\").",
"examples": [
"text"
],
"type": "string",
"enum": [
"text",
"vector",
"hybrid"
]
}Variants