pub struct BalancesAsset {
pub decimals: i64,
pub name: String,
pub symbol: Asset,
pub type_: AssetType,
}Expand description
An asset, e.g. fiat or crypto.
JSON schema
{
"description": "An asset, e.g. fiat or crypto.",
"examples": [
{
"decimals": 8,
"name": "Bitcoin",
"symbol": "btc",
"type": "crypto"
}
],
"type": "object",
"required": [
"decimals",
"name",
"symbol",
"type"
],
"properties": {
"decimals": {
"description": "The number of decimals (i.e. significant digits to the right of the decimal point) supported for the asset.",
"type": "integer"
},
"name": {
"description": "The name of the asset.",
"type": "string"
},
"symbol": {
"$ref": "#/components/schemas/Asset"
},
"type": {
"$ref": "#/components/schemas/AssetType"
}
}
}Fields
decimals: i64The number of decimals (i.e. significant digits to the right of the decimal point) supported for the asset.
name: StringThe name of the asset.
symbol: Assettype_: AssetTypeImplementations
Sourceimpl BalancesAsset
impl BalancesAsset
pub fn builder() -> BalancesAsset