pub struct CreateDelegationForEndUserAccountBody {
pub expires_at: DateTime<Utc>,
pub wallet_secret_id: CreateDelegationForEndUserAccountBodyWalletSecretId,
}Expand description
CreateDelegationForEndUserAccountBody
JSON schema
{
"type": "object",
"required": [
"expiresAt",
"walletSecretId"
],
"properties": {
"expiresAt": {
"description": "The date until which the delegation is valid.",
"examples": [
"2026-02-03T10:35:00Z"
],
"type": "string",
"format": "date-time"
},
"walletSecretId": {
"description": "The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.",
"examples": [
"e051beeb-7163-4527-a5b6-35e301529ff2"
],
"type": "string",
"pattern": "^[a-zA-Z0-9-]{1,100}$"
}
}
}Fields
expires_at: DateTime<Utc>The date until which the delegation is valid.
wallet_secret_id: CreateDelegationForEndUserAccountBodyWalletSecretIdThe ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.
Implementations