pub struct CreateEndUserEvmSwapRule {
pub action: CreateEndUserEvmSwapRuleAction,
pub criteria: CreateEndUserEvmSwapCriteria,
pub operation: CreateEndUserEvmSwapRuleOperation,
}Expand description
CreateEndUserEvmSwapRule
JSON schema
{
"title": "CreateEndUserEvmSwapRule",
"required": [
"action",
"criteria",
"operation"
],
"properties": {
"action": {
"description": "Whether matching the rule will cause the request to be rejected or accepted.",
"examples": [
"accept"
],
"type": "string",
"enum": [
"reject",
"accept"
]
},
"criteria": {
"$ref": "#/components/schemas/CreateEndUserEvmSwapCriteria"
},
"operation": {
"description": "The operation to which the rule applies. Every element of the `criteria` array must match the specified operation.",
"examples": [
"createEndUserEvmSwap"
],
"type": "string",
"enum": [
"createEndUserEvmSwap"
]
}
},
"x-audience": "public"
}Fields
action: CreateEndUserEvmSwapRuleActionWhether matching the rule will cause the request to be rejected or accepted.
criteria: CreateEndUserEvmSwapCriteriaoperation: CreateEndUserEvmSwapRuleOperationThe operation to which the rule applies. Every element of the criteria array must match the specified operation.
Implementations
Sourceimpl CreateEndUserEvmSwapRule
impl CreateEndUserEvmSwapRule
pub fn builder() -> CreateEndUserEvmSwapRule