pub struct DepositDestinationCrypto {
pub address: BlockchainAddress,
pub network: Network,
}Expand description
Crypto-specific deposit destination details. In responses, this object is always present. Contains the network and address for the deposit destination.
JSON schema
{
"description": "Crypto-specific deposit destination details. In responses, this object is always present. Contains the network and address for the deposit destination.",
"examples": [
{
"address": "0x742d35Cc6634C0532925a3b844Bc454e4438f44e",
"network": "base"
}
],
"type": "object",
"required": [
"address",
"network"
],
"properties": {
"address": {
"$ref": "#/components/schemas/BlockchainAddress"
},
"network": {
"$ref": "#/components/schemas/Network"
}
}
}Fields
address: BlockchainAddressnetwork: NetworkImplementations
Sourceimpl DepositDestinationCrypto
impl DepositDestinationCrypto
pub fn builder() -> DepositDestinationCrypto