pub struct DepositDestinationReference {
pub id: DepositDestinationId,
}Expand description
A reference to the deposit destination associated with the transfer.
JSON schema
{
"description": "A reference to the deposit destination associated with the transfer.",
"examples": [
{
"id": "depositDestination_af2937b0-9846-4fe7-bfe9-ccc22d935114"
}
],
"type": "object",
"required": [
"id"
],
"properties": {
"id": {
"$ref": "#/components/schemas/DepositDestinationId"
}
}
}Fields
id: DepositDestinationIdImplementations