pub struct DepositTravelRuleVasp {
pub identifier: Option<String>,
pub name: Option<String>,
}Expand description
Information about the Virtual Asset Service Provider (VASP) for a deposit travel rule submission.
JSON schema
{
"description": "Information about the Virtual Asset Service Provider (VASP) for a deposit travel rule submission.",
"examples": [
{
"identifier": "5493001KJTIIGC8Y1R17",
"name": "Fidelity Digital Asset Services, LLC"
}
],
"type": "object",
"properties": {
"identifier": {
"description": "The Legal Entity Identifier (LEI) of the Virtual Asset Service Provider (VASP).",
"examples": [
"5493001KJTIIGC8Y1R17"
],
"type": "string"
},
"name": {
"description": "The name of the Virtual Asset Service Provider (VASP).",
"examples": [
"Fidelity Digital Asset Services, LLC"
],
"type": "string"
}
}
}Fields
identifier: Option<String>The Legal Entity Identifier (LEI) of the Virtual Asset Service Provider (VASP).
name: Option<String>The name of the Virtual Asset Service Provider (VASP).
Implementations
Sourceimpl DepositTravelRuleVasp
impl DepositTravelRuleVasp
pub fn builder() -> DepositTravelRuleVasp