pub struct EmailAddress {
pub email: Email,
}Expand description
The target of the payment is an email address.
JSON schema
{
"title": "Email Address",
"description": "The target of the payment is an email address.",
"examples": [
{
"email": "recipient@example.com"
}
],
"type": "object",
"required": [
"email"
],
"properties": {
"email": {
"description": "The email address of the recipient. The recipient will need to have an account with Coinbase or onboard to Coinbase to receive the payment.",
"examples": [
"recipient@example.com"
],
"allOf": [
{
"$ref": "#/components/schemas/Email"
}
]
}
}
}Fields
email: EmailThe email address of the recipient. The recipient will need to have an account with Coinbase or onboard to Coinbase to receive the payment.
Implementations
Sourceimpl EmailAddress
impl EmailAddress
pub fn builder() -> EmailAddress