pub struct EmailInstrument {
pub asset: Asset,
pub email: Email,
}Expand description
The target of the payment is an email address.
JSON schema
{
"title": "Email Instrument",
"description": "The target of the payment is an email address.",
"examples": [
{
"asset": "usd",
"email": "recipient@example.com"
}
],
"allOf": [
{
"$ref": "#/components/schemas/EmailAddress"
},
{
"type": "object",
"required": [
"asset"
],
"properties": {
"asset": {
"description": "Asset symbol of the payment received by the recipient.",
"allOf": [
{
"$ref": "#/components/schemas/Asset"
}
]
}
}
}
]
}Fields
asset: AssetAsset symbol of the payment received by the recipient.
email: EmailThe email address of the recipient. The recipient will need to have an account with Coinbase or onboard to Coinbase to receive the payment.
Implementations
Sourceimpl EmailInstrument
impl EmailInstrument
pub fn builder() -> EmailInstrument