MfaMethods

Struct MfaMethods 

pub struct MfaMethods {
    pub enrollment_prompted_at: Option<DateTime<Utc>>,
    pub sms: Option<MfaMethodsSms>,
    pub totp: Option<MfaMethodsTotp>,
}
Information about the end user’s MFA enrollments.

JSON schema
{
 "description": "Information about the end user's MFA enrollments.\n",
 "examples": [
   {
     "enrollmentPromptedAt": "2025-01-15T10:30:00Z",
     "sms": {
       "enrolledAt": "2025-01-15T10:30:00Z"
     },
     "totp": {
       "enrolledAt": "2025-01-15T10:30:00Z"
     }
   }
 ],
 "type": "object",
 "properties": {
   "enrollmentPromptedAt": {
     "description": "The date and time when the end user was prompted for MFA enrollment, in ISO 8601 format. If the this field exists, and the user has no other enrolled MFA methods, then the user skipped MFA enrollment.",
     "examples": [
       "2025-01-15T10:30:00Z"
     ],
     "type": "string",
     "format": "date-time"
   },
   "sms": {
     "description": "An object containing information about the end user's SMS MFA enrollment.",
     "type": "object",
     "required": [
       "enrolledAt"
     ],
     "properties": {
       "enrolledAt": {
         "description": "The date and time when the method was enrolled, in ISO 8601 format.",
         "examples": [
           "2025-01-15T10:30:00Z"
         ],
         "type": "string",
         "format": "date-time"
       }
     }
   },
   "totp": {
     "description": "An object containing information about the end user's TOTP enrollment.",
     "type": "object",
     "required": [
       "enrolledAt"
     ],
     "properties": {
       "enrolledAt": {
         "description": "The date and time when the method was enrolled, in ISO 8601 format.",
         "examples": [
           "2025-01-15T10:30:00Z"
         ],
         "type": "string",
         "format": "date-time"
       }
     }
   }
 },
 "x-audience": "public"
}

Fields

enrollment_prompted_at: Option<DateTime<Utc>>

The date and time when the end user was prompted for MFA enrollment, in ISO 8601 format. If the this field exists, and the user has no other enrolled MFA methods, then the user skipped MFA enrollment.

sms: Option<MfaMethodsSms>totp: Option<MfaMethodsTotp>

Implementations