pub struct MfaMethodsSms {
pub enrolled_at: DateTime<Utc>,
}Expand description
An object containing information about the end user’s SMS MFA enrollment.
JSON schema
{
"description": "An object containing information about the end user's SMS MFA enrollment.",
"type": "object",
"required": [
"enrolledAt"
],
"properties": {
"enrolledAt": {
"description": "The date and time when the method was enrolled, in ISO 8601 format.",
"examples": [
"2025-01-15T10:30:00Z"
],
"type": "string",
"format": "date-time"
}
}
}Fields
enrolled_at: DateTime<Utc>The date and time when the method was enrolled, in ISO 8601 format.
Implementations
Sourceimpl MfaMethodsSms
impl MfaMethodsSms
pub fn builder() -> MfaMethodsSms