pub struct OriginatingBankAccountUs {
pub account_last4: OriginatingBankAccountUsAccountLast4,
pub bank_name: String,
pub currency: String,
}Expand description
The originating US bank account details for the transfer source. Present when funds were deposited from an external bank account into a deposit destination. Only the last 4 digits of the account number are exposed.
JSON schema
{
"title": "Originating Bank Account (US)",
"description": "The originating US bank account details for the transfer source. Present when funds were deposited from an external bank account into a deposit destination. Only the last 4 digits of the account number are exposed.",
"examples": [
{
"accountLast4": "6789",
"bankName": "Citibank, N.A.",
"currency": "usd"
}
],
"type": "object",
"required": [
"accountLast4",
"bankName",
"currency"
],
"properties": {
"accountLast4": {
"description": "The last 4 digits of the originating bank account number.",
"examples": [
"6789"
],
"type": "string",
"pattern": "^[0-9]{4}$"
},
"bankName": {
"description": "The name of the bank that originated the deposit.",
"examples": [
"Citibank, N.A."
],
"type": "string"
},
"currency": {
"description": "The fiat currency of the deposit (e.g., `usd`).",
"examples": [
"usd"
],
"type": "string"
}
}
}Fields
account_last4: OriginatingBankAccountUsAccountLast4The last 4 digits of the originating bank account number.
bank_name: StringThe name of the bank that originated the deposit.
currency: StringThe fiat currency of the deposit (e.g., usd).
Implementations
Sourceimpl OriginatingBankAccountUs
impl OriginatingBankAccountUs
pub fn builder() -> OriginatingBankAccountUs