pub struct PhysicalAddress {
pub city: Option<String>,
pub country_code: Option<PhysicalAddressCountryCode>,
pub line1: Option<String>,
pub line2: Option<String>,
pub post_code: Option<String>,
pub state: Option<String>,
}Expand description
A physical address with standard address components including street, city, state/province, postal code, and country.
JSON schema
{
"description": "A physical address with standard address components including street, city, state/province, postal code, and country.",
"type": "object",
"properties": {
"city": {
"description": "City or locality.",
"examples": [
"San Francisco"
],
"type": "string"
},
"countryCode": {
"description": "ISO 3166-1 alpha-2 country code (2 characters). See https://en.wikipedia.org/wiki/List_of_ISO_3166_country_codes.",
"examples": [
"US"
],
"type": "string",
"maxLength": 2,
"minLength": 2
},
"line1": {
"description": "Primary street address.",
"examples": [
"123 Market St"
],
"type": "string"
},
"line2": {
"description": "Secondary address information.",
"examples": [
"Suite 400"
],
"type": "string"
},
"postCode": {
"description": "Postal or ZIP code.",
"examples": [
"94105"
],
"type": "string"
},
"state": {
"description": "State, province, or region.",
"examples": [
"CA"
],
"type": "string"
}
}
}Fields
city: Option<String>City or locality.
country_code: Option<PhysicalAddressCountryCode>ISO 3166-1 alpha-2 country code (2 characters). See https://en.wikipedia.org/wiki/List_of_ISO_3166_country_codes.
line1: Option<String>Primary street address.
line2: Option<String>Secondary address information.
post_code: Option<String>Postal or ZIP code.
state: Option<String>State, province, or region.
Implementations
Sourceimpl PhysicalAddress
impl PhysicalAddress
pub fn builder() -> PhysicalAddress