pub struct SendEndUserEvmTransactionRule {
pub action: SendEndUserEvmTransactionRuleAction,
pub criteria: SendEndUserEvmTransactionCriteria,
pub operation: SendEndUserEvmTransactionRuleOperation,
}Expand description
SendEndUserEvmTransactionRule
JSON schema
{
"title": "SendEndUserEvmTransactionRule",
"required": [
"action",
"criteria",
"operation"
],
"properties": {
"action": {
"description": "Whether matching the rule will cause the request to be rejected or accepted.",
"examples": [
"accept"
],
"type": "string",
"enum": [
"reject",
"accept"
]
},
"criteria": {
"$ref": "#/components/schemas/SendEndUserEvmTransactionCriteria"
},
"operation": {
"description": "The operation to which the rule applies. Every element of the `criteria` array must match the specified operation.",
"examples": [
"sendEndUserEvmTransaction"
],
"type": "string",
"enum": [
"sendEndUserEvmTransaction"
]
}
},
"x-audience": "public"
}Fields
action: SendEndUserEvmTransactionRuleActionWhether matching the rule will cause the request to be rejected or accepted.
criteria: SendEndUserEvmTransactionCriteriaoperation: SendEndUserEvmTransactionRuleOperationThe operation to which the rule applies. Every element of the criteria array must match the specified operation.
Implementations