pub struct SendEndUserOperationRule {
pub action: SendEndUserOperationRuleAction,
pub criteria: SendEndUserOperationCriteria,
pub operation: SendEndUserOperationRuleOperation,
}Expand description
SendEndUserOperationRule
JSON schema
{
"title": "SendEndUserOperationRule",
"required": [
"action",
"criteria",
"operation"
],
"properties": {
"action": {
"description": "Whether matching the rule will cause the request to be rejected or accepted.",
"examples": [
"accept"
],
"type": "string",
"enum": [
"reject",
"accept"
]
},
"criteria": {
"$ref": "#/components/schemas/SendEndUserOperationCriteria"
},
"operation": {
"description": "The operation to which the rule applies. Every element of the `criteria` array must match the specified operation.",
"examples": [
"sendEndUserOperation"
],
"type": "string",
"enum": [
"sendEndUserOperation"
]
}
},
"x-audience": "public"
}Fields
action: SendEndUserOperationRuleActionWhether matching the rule will cause the request to be rejected or accepted.
criteria: SendEndUserOperationCriteriaoperation: SendEndUserOperationRuleOperationThe operation to which the rule applies. Every element of the criteria array must match the specified operation.
Implementations
Sourceimpl SendEndUserOperationRule
impl SendEndUserOperationRule
pub fn builder() -> SendEndUserOperationRule