pub struct SendEndUserSolTransactionRule {
pub action: SendEndUserSolTransactionRuleAction,
pub criteria: SendEndUserSolTransactionCriteria,
pub operation: SendEndUserSolTransactionRuleOperation,
}Expand description
SendEndUserSolTransactionRule
JSON schema
{
"title": "SendEndUserSolTransactionRule",
"required": [
"action",
"criteria",
"operation"
],
"properties": {
"action": {
"description": "Whether matching the rule will cause the request to be rejected or accepted.",
"examples": [
"accept"
],
"type": "string",
"enum": [
"reject",
"accept"
]
},
"criteria": {
"$ref": "#/components/schemas/SendEndUserSolTransactionCriteria"
},
"operation": {
"description": "The operation to which the rule applies. Every element of the `criteria` array must match the specified operation.",
"examples": [
"sendEndUserSolTransaction"
],
"type": "string",
"enum": [
"sendEndUserSolTransaction"
]
}
},
"x-audience": "public"
}Fields
action: SendEndUserSolTransactionRuleActionWhether matching the rule will cause the request to be rejected or accepted.
criteria: SendEndUserSolTransactionCriteriaoperation: SendEndUserSolTransactionRuleOperationThe operation to which the rule applies. Every element of the criteria array must match the specified operation.
Implementations