SendEvmAssetWithEndUserAccountBody

Struct SendEvmAssetWithEndUserAccountBody 

pub struct SendEvmAssetWithEndUserAccountBody {
    pub amount: SendEvmAssetWithEndUserAccountBodyAmount,
    pub network: SendEvmAssetWithEndUserAccountBodyNetwork,
    pub paymaster_url: Option<Url>,
    pub to: BlockchainAddress,
    pub use_cdp_paymaster: Option<bool>,
    pub wallet_secret_id: Option<SendEvmAssetWithEndUserAccountBodyWalletSecretId>,
}
SendEvmAssetWithEndUserAccountBody

JSON schema
{
 "type": "object",
 "required": [
   "amount",
   "network",
   "to"
 ],
 "properties": {
   "amount": {
     "description": "The amount of USDC to send as a decimal string (e.g., \"1.5\" or \"25.50\").",
     "examples": [
       "1.50"
     ],
     "type": "string",
     "maxLength": 32,
     "minLength": 1
   },
   "network": {
     "description": "The EVM network to send USDC on.",
     "examples": [
       "base-sepolia"
     ],
     "type": "string",
     "enum": [
       "base",
       "base-sepolia",
       "ethereum",
       "ethereum-sepolia",
       "avalanche",
       "polygon",
       "optimism",
       "arbitrum",
       "arbitrum-sepolia",
       "world",
       "world-sepolia"
     ]
   },
   "paymasterUrl": {
     "description": "Optional custom Paymaster URL to use for gas sponsorship. Only applicable for EVM Smart Accounts. This allows you to use your own Paymaster service instead of CDP's Paymaster. Cannot be used together with `useCdpPaymaster`.",
     "examples": [
       "https://api.developer.coinbase.com/rpc/v1/base/AbCdEf123456"
     ],
     "allOf": [
       {
         "$ref": "#/components/schemas/Url"
       }
     ]
   },
   "to": {
     "$ref": "#/components/schemas/BlockchainAddress"
   },
   "useCdpPaymaster": {
     "description": "Whether to use CDP Paymaster to sponsor gas fees. Only applicable for EVM Smart Accounts. When true, the transaction gas will be paid by the Paymaster, allowing users to send USDC without holding native gas tokens. Ignored for EOA accounts. Cannot be used together with `paymasterUrl`.",
     "examples": [
       true
     ],
     "type": "boolean"
   },
   "walletSecretId": {
     "description": "Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.",
     "examples": [
       "e051beeb-7163-4527-a5b6-35e301529ff2"
     ],
     "type": "string",
     "pattern": "^[a-zA-Z0-9-]{1,100}$"
   }
 }
}

Fields

amount: SendEvmAssetWithEndUserAccountBodyAmount

The amount of USDC to send as a decimal string (e.g., “1.5” or “25.50”).

network: SendEvmAssetWithEndUserAccountBodyNetwork

The EVM network to send USDC on.

paymaster_url: Option<Url>

Optional custom Paymaster URL to use for gas sponsorship. Only applicable for EVM Smart Accounts. This allows you to use your own Paymaster service instead of CDP’s Paymaster. Cannot be used together with useCdpPaymaster.

to: BlockchainAddressuse_cdp_paymaster: Option<bool>

Whether to use CDP Paymaster to sponsor gas fees. Only applicable for EVM Smart Accounts. When true, the transaction gas will be paid by the Paymaster, allowing users to send USDC without holding native gas tokens. Ignored for EOA accounts. Cannot be used together with paymasterUrl.

wallet_secret_id: Option<SendEvmAssetWithEndUserAccountBodyWalletSecretId>

Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.

Implementations