SendSolanaTransactionBody

Struct SendSolanaTransactionBody 

pub struct SendSolanaTransactionBody {
    pub network: SendSolanaTransactionBodyNetwork,
    pub transaction: String,
    pub use_cdp_sponsor: Option<bool>,
}
SendSolanaTransactionBody

JSON schema
{
 "type": "object",
 "required": [
   "network",
   "transaction"
 ],
 "properties": {
   "network": {
     "description": "The Solana network to send the transaction to.",
     "examples": [
       "solana-devnet"
     ],
     "type": "string",
     "enum": [
       "solana",
       "solana-devnet"
     ]
   },
   "transaction": {
     "description": "The base64 encoded transaction to sign and send. This transaction can contain multiple instructions for native Solana batching.",
     "examples": [
       "AQABAgIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAQABAQECAwQFBgcICQoLDA0ODxAREhMUFRYXGBkaGxwdHh8CBgMBAQAAAAIBAwQAAAAABgIAAAAAAAYDBQEBAAAGBAgAAAAABgUAAAAA6AMAAAAAAAAGBgUBAQEBBgcEAQAAAAYICgMBAQIDBgkCBgAAAAYKAwABAQEGCwMGAQEBBgwDAAABAQAAAAA="
     ],
     "type": "string"
   },
   "useCdpSponsor": {
     "description": "Whether transaction fees should be sponsored by CDP. When true, CDP sponsors the transaction fees on behalf of the server wallet. When false, the server wallet is responsible for paying the transaction fees.",
     "examples": [
       true
     ],
     "type": "boolean"
   }
 }
}

Fields

network: SendSolanaTransactionBodyNetwork

The Solana network to send the transaction to.

transaction: String

The base64 encoded transaction to sign and send. This transaction can contain multiple instructions for native Solana batching.

use_cdp_sponsor: Option<bool>

Whether transaction fees should be sponsored by CDP. When true, CDP sponsors the transaction fees on behalf of the server wallet. When false, the server wallet is responsible for paying the transaction fees.

Implementations