pub struct SignEndUserEvmTypedDataRule {
pub action: SignEndUserEvmTypedDataRuleAction,
pub criteria: SignEndUserEvmTypedDataCriteria,
pub operation: SignEndUserEvmTypedDataRuleOperation,
}Expand description
SignEndUserEvmTypedDataRule
JSON schema
{
"title": "SignEndUserEvmTypedDataRule",
"required": [
"action",
"criteria",
"operation"
],
"properties": {
"action": {
"description": "Whether matching the rule will cause the request to be rejected or accepted.",
"examples": [
"accept"
],
"type": "string",
"enum": [
"reject",
"accept"
]
},
"criteria": {
"$ref": "#/components/schemas/SignEndUserEvmTypedDataCriteria"
},
"operation": {
"description": "The operation to which the rule applies. Every element of the `criteria` array must match the specified operation.",
"examples": [
"signEndUserEvmTypedData"
],
"type": "string",
"enum": [
"signEndUserEvmTypedData"
]
}
},
"x-audience": "public"
}Fields
action: SignEndUserEvmTypedDataRuleActionWhether matching the rule will cause the request to be rejected or accepted.
criteria: SignEndUserEvmTypedDataCriteriaoperation: SignEndUserEvmTypedDataRuleOperationThe operation to which the rule applies. Every element of the criteria array must match the specified operation.
Implementations