pub struct SignSolanaTransactionWithEndUserAccountBody {
pub address: SignSolanaTransactionWithEndUserAccountBodyAddress,
pub transaction: String,
pub wallet_secret_id: Option<SignSolanaTransactionWithEndUserAccountBodyWalletSecretId>,
}Expand description
SignSolanaTransactionWithEndUserAccountBody
JSON schema
{
"type": "object",
"required": [
"address",
"transaction"
],
"properties": {
"address": {
"description": "The base58 encoded address of the Solana account belonging to the end user.",
"examples": [
"HpabPRRCFbBKSuJr5PdkVvQc85FyxyTWkFM2obBRSvHT"
],
"type": "string",
"pattern": "^[1-9A-HJ-NP-Za-km-z]{32,44}$"
},
"transaction": {
"description": "The base64 encoded transaction to sign.",
"examples": [
"AQABAgIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAQABAQECAwQFBgcICQoLDA0ODxAREhMUFRYXGBkaGxwdHh8CBgMBAQAAAAIBAwQAAAAABgIAAAAAAAYDBQEBAAAGBAgAAAAABgUAAAAA6AMAAAAAAAAGBgUBAQEBBgcEAQAAAAYICgMBAQIDBgkCBgAAAAYKAwABAQEGCwMGAQEBBgwDAAABAQAAAAA="
],
"type": "string"
},
"walletSecretId": {
"description": "Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.",
"examples": [
"e051beeb-7163-4527-a5b6-35e301529ff2"
],
"type": "string",
"pattern": "^[a-zA-Z0-9-]{1,100}$"
}
}
}Fields
address: SignSolanaTransactionWithEndUserAccountBodyAddressThe base58 encoded address of the Solana account belonging to the end user.
transaction: StringThe base64 encoded transaction to sign.
wallet_secret_id: Option<SignSolanaTransactionWithEndUserAccountBodyWalletSecretId>Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.
Implementations