pub struct TelegramAuthentication {
pub auth_date: i64,
pub first_name: Option<String>,
pub id: i64,
pub last_name: Option<String>,
pub photo_url: Option<String>,
pub type_: OAuth2ProviderType,
pub username: Option<String>,
}Expand description
Information about an end user who authenticates using Telegram.
JSON schema
{
"description": "Information about an end user who authenticates using Telegram.",
"type": "object",
"required": [
"authDate",
"id",
"type"
],
"properties": {
"authDate": {
"description": "The Telegram user's last login as a Unix timestamp.",
"examples": [
1770681412
],
"type": "integer"
},
"firstName": {
"description": "The Telegram user's first name.",
"examples": [
"Satoshi"
],
"type": "string"
},
"id": {
"description": "The Telegram ID for the end user.",
"examples": [
123456
],
"type": "integer"
},
"lastName": {
"description": "The Telegram user's last name.",
"examples": [
"Nakamoto"
],
"type": "string"
},
"photoUrl": {
"description": "The Telegram user's profile picture.",
"examples": [
"https://image.url/profile.png"
],
"type": "string"
},
"type": {
"$ref": "#/components/schemas/OAuth2ProviderType"
},
"username": {
"description": "The Telegram user's username.",
"examples": [
"satoshinakamoto"
],
"type": "string"
}
}
}Fields
auth_date: i64The Telegram user’s last login as a Unix timestamp.
first_name: Option<String>The Telegram user’s first name.
id: i64The Telegram ID for the end user.
last_name: Option<String>The Telegram user’s last name.
photo_url: Option<String>The Telegram user’s profile picture.
type_: OAuth2ProviderTypeusername: Option<String>The Telegram user’s username.
Implementations
Sourceimpl TelegramAuthentication
impl TelegramAuthentication
pub fn builder() -> TelegramAuthentication