pub struct Transfer {Show 19 fields
pub completed_at: Option<DateTime<Utc>>,
pub created_at: Option<DateTime<Utc>>,
pub details: Option<TransferDetails>,
pub estimate: Option<TransferEstimate>,
pub exchange_rate: Option<TransferExchangeRate>,
pub executed_at: Option<DateTime<Utc>>,
pub expires_at: Option<DateTime<Utc>>,
pub failure_reason: Option<String>,
pub fees: Option<TransferFees>,
pub metadata: Option<Metadata>,
pub source: TransferSource,
pub source_amount: Option<String>,
pub source_asset: Option<Asset>,
pub status: Option<TransferStatus>,
pub target: TransferTarget,
pub target_amount: Option<String>,
pub target_asset: Option<Asset>,
pub transfer_id: Option<String>,
pub updated_at: Option<DateTime<Utc>>,
}Expand description
A Transfer represents all the information needed to execute a transfer and tracks the lifecycle of a transfer from initiation through completion or failure.
JSON schema
{
"description": "A Transfer represents all the information needed to execute a transfer and tracks the lifecycle of a transfer from initiation through completion or failure.",
"type": "object",
"required": [
"source",
"target"
],
"properties": {
"completedAt": {
"description": "The date and time the transfer was completed.",
"examples": [
"2025-01-01T00:05:00Z"
],
"type": "string",
"format": "date-time"
},
"createdAt": {
"description": "The date and time the transfer was created. Required when validateOnly is false.",
"examples": [
"2025-01-01T00:00:00Z"
],
"type": "string",
"format": "date-time"
},
"details": {
"$ref": "#/components/schemas/TransferDetails"
},
"estimate": {
"$ref": "#/components/schemas/TransferEstimate"
},
"exchangeRate": {
"$ref": "#/components/schemas/TransferExchangeRate"
},
"executedAt": {
"description": "The date and time the transfer was executed and moved to processing. Only present when status has progressed beyond `quoted`.",
"examples": [
"2025-01-01T00:01:30Z"
],
"type": "string",
"format": "date-time"
},
"expiresAt": {
"description": "The date and time when this transfer will expire if not executed. Only present for `quoted` status. A new transfer must be created to obtain an updated quote after expiration. Required when validateOnly is false.",
"examples": [
"2025-01-01T00:15:00Z"
],
"type": "string",
"format": "date-time"
},
"failureReason": {
"description": "The reason for failure, if the transfer failed. Only present when status is `failed`.",
"examples": [
"Insufficient balance to complete this transfer."
],
"type": "string"
},
"fees": {
"$ref": "#/components/schemas/TransferFees"
},
"metadata": {
"$ref": "#/components/schemas/Metadata"
},
"source": {
"$ref": "#/components/schemas/TransferSource"
},
"sourceAmount": {
"description": "The amount of the source asset that will be transferred out, as a decimal string in standard unit denomination.",
"examples": [
"103.50"
],
"type": "string"
},
"sourceAsset": {
"description": "The asset symbol of the source amount.",
"examples": [
"usd"
],
"allOf": [
{
"$ref": "#/components/schemas/Asset"
}
]
},
"status": {
"$ref": "#/components/schemas/TransferStatus"
},
"target": {
"$ref": "#/components/schemas/TransferTarget"
},
"targetAmount": {
"description": "The amount of the target asset that will be received, as a decimal string in standard unit denomination.",
"examples": [
"100.00"
],
"type": "string"
},
"targetAsset": {
"description": "The asset symbol of the target amount.",
"examples": [
"usdc"
],
"allOf": [
{
"$ref": "#/components/schemas/Asset"
}
]
},
"transferId": {
"description": "The ID of the transfer. Required when validateOnly is false.",
"examples": [
"transfer_af2937b0-9846-4fe7-bfe9-ccc22d935114"
],
"type": "string"
},
"updatedAt": {
"description": "The date and time the transfer was last updated. Required when validateOnly is false.",
"examples": [
"2025-01-01T00:00:00Z"
],
"type": "string",
"format": "date-time"
}
}
}Fields
completed_at: Option<DateTime<Utc>>The date and time the transfer was completed.
created_at: Option<DateTime<Utc>>The date and time the transfer was created. Required when validateOnly is false.
details: Option<TransferDetails>estimate: Option<TransferEstimate>exchange_rate: Option<TransferExchangeRate>executed_at: Option<DateTime<Utc>>The date and time the transfer was executed and moved to processing. Only present when status has progressed beyond quoted.
expires_at: Option<DateTime<Utc>>The date and time when this transfer will expire if not executed. Only present for quoted status. A new transfer must be created to obtain an updated quote after expiration. Required when validateOnly is false.
failure_reason: Option<String>The reason for failure, if the transfer failed. Only present when status is failed.
fees: Option<TransferFees>metadata: Option<Metadata>source: TransferSourcesource_amount: Option<String>The amount of the source asset that will be transferred out, as a decimal string in standard unit denomination.
source_asset: Option<Asset>The asset symbol of the source amount.
status: Option<TransferStatus>target: TransferTargettarget_amount: Option<String>The amount of the target asset that will be received, as a decimal string in standard unit denomination.
target_asset: Option<Asset>The asset symbol of the target amount.
transfer_id: Option<String>The ID of the transfer. Required when validateOnly is false.
updated_at: Option<DateTime<Utc>>The date and time the transfer was last updated. Required when validateOnly is false.