pub struct TransferDetails {
pub deposit_destination: Option<DepositDestinationReference>,
pub onchain_transactions: Vec<TransferDetailsOnchainTransactionsItem>,
pub travel_rule: Option<TransferDetailsTravelRule>,
}Expand description
Additional details about the transfer. For example, if the transfer was sent to a deposit destination, the information about that destination will be included in this field.
JSON schema
{
"description": "Additional details about the transfer. For example, if the transfer was sent to a deposit destination, the information about that destination will be included in this field.",
"examples": [
{
"depositDestination": {
"id": "depositDestination_af2937b0-9846-4fe7-bfe9-ccc22d935114"
},
"onchainTransactions": [
{
"network": "base",
"transactionHash": "0x363cd3b3d4f49497cf5076150cd709307b90e9fc897fdd623546ea7b9313cecb"
}
]
}
],
"type": "object",
"properties": {
"depositDestination": {
"$ref": "#/components/schemas/DepositDestinationReference"
},
"onchainTransactions": {
"description": "The onchain transactions associated with the transfer.",
"examples": [
[
{
"network": "base",
"transactionHash": "0x363cd3b3d4f49497cf5076150cd709307b90e9fc897fdd623546ea7b9313cecb"
}
]
],
"type": "array",
"items": {
"description": "An onchain transaction associated with the transfer.",
"type": "object",
"required": [
"network",
"transactionHash"
],
"properties": {
"network": {
"$ref": "#/components/schemas/Network"
},
"transactionHash": {
"description": "The transaction hash.",
"examples": [
"0x363cd3b3d4f49497cf5076150cd709307b90e9fc897fdd623546ea7b9313cecb"
],
"type": "string"
}
}
}
},
"travelRule": {
"description": "Travel rule compliance status for deposit transfers. Present when the transfer requires travel rule information.",
"examples": [
{
"status": "incomplete",
"statusMessage": "Originator date of birth is required."
}
],
"type": "object",
"properties": {
"status": {
"$ref": "#/components/schemas/TravelRuleStatus"
},
"statusMessage": {
"description": "Additional details about the current travel rule status. For example, when status is `incomplete`, this may indicate the specific missing information required to proceed.",
"examples": [
"Originator date of birth is required."
],
"type": "string"
}
}
}
}
}Fields
deposit_destination: Option<DepositDestinationReference>onchain_transactions: Vec<TransferDetailsOnchainTransactionsItem>The onchain transactions associated with the transfer.
travel_rule: Option<TransferDetailsTravelRule>Implementations
Sourceimpl TransferDetails
impl TransferDetails
pub fn builder() -> TransferDetails