pub struct TransferExchangeRate {
pub rate: String,
pub source_asset: Asset,
pub target_asset: Asset,
}Expand description
Exchange rate information for currency conversion. The rate indicates how much of the target asset is equivalent to one unit of the source asset.
JSON schema
{
"description": "Exchange rate information for currency conversion. The rate indicates how much of the target asset is equivalent to one unit of the source asset.",
"examples": [
{
"rate": "1",
"sourceAsset": "usd",
"targetAsset": "usdc"
}
],
"type": "object",
"required": [
"rate",
"sourceAsset",
"targetAsset"
],
"properties": {
"rate": {
"description": "The exchange rate value as a decimal string. Indicates how many units of the target asset equal one unit of the source asset.",
"examples": [
"1"
],
"type": "string"
},
"sourceAsset": {
"description": "The asset being converted from.",
"examples": [
"usd"
],
"allOf": [
{
"$ref": "#/components/schemas/Asset"
}
]
},
"targetAsset": {
"description": "The asset being converted to.",
"examples": [
"usdc"
],
"allOf": [
{
"$ref": "#/components/schemas/Asset"
}
]
}
}
}Fields
rate: StringThe exchange rate value as a decimal string. Indicates how many units of the target asset equal one unit of the source asset.
source_asset: AssetThe asset being converted from.
target_asset: AssetThe asset being converted to.
Implementations
Sourceimpl TransferExchangeRate
impl TransferExchangeRate
pub fn builder() -> TransferExchangeRate