pub struct TransferFee {
pub amount: String,
pub asset: Asset,
pub type_: TransferFeeType,
}Expand description
A single fee for a transfer.
JSON schema
{
"description": "A single fee for a transfer.",
"type": "object",
"required": [
"amount",
"asset",
"type"
],
"properties": {
"amount": {
"description": "The amount of the fee in units of the asset specified by `asset`.",
"examples": [
"1500000"
],
"type": "string"
},
"asset": {
"description": "The asset symbol.",
"examples": [
"usd"
],
"allOf": [
{
"$ref": "#/components/schemas/Asset"
}
]
},
"type": {
"description": "The type of the fee, indicating its purpose.",
"examples": [
"network"
],
"type": "string",
"enum": [
"bank",
"conversion",
"network",
"other"
],
"x-enum-varnames": [
"BankFee",
"ConversionFee",
"NetworkFee",
"OtherFee"
]
}
}
}Fields
amount: StringThe amount of the fee in units of the asset specified by asset.
asset: AssetThe asset symbol.
type_: TransferFeeTypeThe type of the fee, indicating its purpose.
Implementations
Sourceimpl TransferFee
impl TransferFee
pub fn builder() -> TransferFee