pub struct X402DiscoveryMerchantResponsePagination {
pub limit: Option<i64>,
pub offset: Option<i64>,
pub total: Option<i64>,
}Expand description
Pagination information for the response.
JSON schema
{
"description": "Pagination information for the response.",
"examples": [
{
"limit": 20,
"offset": 0,
"total": 10
}
],
"type": "object",
"properties": {
"limit": {
"description": "The number of resources returned per page.",
"examples": [
20
],
"type": "integer"
},
"offset": {
"description": "The offset of the first resource returned.",
"examples": [
0
],
"type": "integer"
},
"total": {
"description": "The total number of resources associated with the merchant's payTo address.",
"examples": [
10
],
"type": "integer"
}
}
}Fields
limit: Option<i64>The number of resources returned per page.
offset: Option<i64>The offset of the first resource returned.
total: Option<i64>The total number of resources associated with the merchant’s payTo address.
Implementations