pub struct X402ExactEvmPermit2Payload {
pub permit2_authorization: X402ExactEvmPermit2PayloadPermit2Authorization,
pub signature: X402ExactEvmPermit2PayloadSignature,
}Expand description
The x402 protocol exact scheme payload for EVM networks using Permit2. Permit2 is a universal token approval mechanism that works with any ERC-20 token, unlike ERC-3009 which requires token-level support.
JSON schema
{
"title": "x402ExactEvmPermit2Payload",
"description": "The x402 protocol exact scheme payload for EVM networks using Permit2. Permit2 is a universal token approval mechanism that works with any ERC-20 token, unlike ERC-3009 which requires token-level support.",
"examples": [
{
"permit2Authorization": {
"deadline": "1716150000",
"from": "0x742d35Cc6634C0532925a3b844Bc454e4438f44e",
"nonce": "12345678901234567890",
"permitted": {
"amount": "1000000",
"token": "0x036CbD53842c5426634e7929541eC2318f3dCF7e"
},
"spender": "0x4020615294c913F045dc10f0a5cdEbd86c280001",
"witness": {
"extra": "0x",
"to": "0x742d35Cc6634C0532925a3b844Bc454e4438f44e",
"validAfter": "1716150000"
}
},
"signature": "0xf3746613c2d920b5fdabc0856f2aeb2d4f88ee6037b8cc5d04a71a4462f134801234567890abcdef1234567890abcdef1234567890abcdef1234567890abcdef1b"
}
],
"type": "object",
"required": [
"permit2Authorization",
"signature"
],
"properties": {
"permit2Authorization": {
"description": "The authorization data for the Permit2 PermitWitnessTransferFrom message.",
"examples": [
{
"deadline": "1716150000",
"from": "0x742d35Cc6634C0532925a3b844Bc454e4438f44e",
"nonce": "12345678901234567890",
"permitted": {
"amount": "1000000",
"token": "0x036CbD53842c5426634e7929541eC2318f3dCF7e"
},
"spender": "0x4020615294c913F045dc10f0a5cdEbd86c280001",
"witness": {
"extra": "0x",
"to": "0x742d35Cc6634C0532925a3b844Bc454e4438f44e",
"validAfter": "1716150000"
}
}
],
"type": "object",
"required": [
"deadline",
"from",
"nonce",
"permitted",
"spender",
"witness"
],
"properties": {
"deadline": {
"description": "The unix timestamp before which the permit is valid.",
"examples": [
"1716150000"
],
"type": "string"
},
"from": {
"description": "The 0x-prefixed, checksum EVM address of the sender of the payment.",
"examples": [
"0x742d35Cc6634C0532925a3b844Bc454e4438f44e"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{40}$"
},
"nonce": {
"description": "The Permit2 nonce as a decimal string (uint256).",
"examples": [
"12345678901234567890"
],
"type": "string",
"pattern": "^[0-9]+$"
},
"permitted": {
"description": "The token permissions for the transfer.",
"type": "object",
"required": [
"amount",
"token"
],
"properties": {
"amount": {
"description": "The amount to transfer in atomic units.",
"examples": [
"1000000"
],
"type": "string"
},
"token": {
"description": "The 0x-prefixed, checksum EVM address of the token to transfer.",
"examples": [
"0x036CbD53842c5426634e7929541eC2318f3dCF7e"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{40}$"
}
}
},
"spender": {
"description": "The 0x-prefixed, checksum EVM address of the spender (x402 Permit2 proxy contract).",
"examples": [
"0x4020615294c913F045dc10f0a5cdEbd86c280001"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{40}$"
},
"witness": {
"description": "The witness data containing payment details.",
"type": "object",
"required": [
"to",
"validAfter"
],
"properties": {
"extra": {
"description": "Optional hex-encoded extra data.",
"examples": [
"0x"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]*$"
},
"to": {
"description": "The 0x-prefixed, checksum EVM address of the recipient.",
"examples": [
"0x742d35Cc6634C0532925a3b844Bc454e4438f44e"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{40}$"
},
"validAfter": {
"description": "The unix timestamp after which the payment is valid.",
"examples": [
"1716150000"
],
"type": "string"
}
}
}
}
},
"signature": {
"description": "The EIP-712 hex-encoded signature of the Permit2 PermitWitnessTransferFrom message. Smart account signatures may be longer than 65 bytes.",
"examples": [
"0xf3746613c2d920b5fdabc0856f2aeb2d4f88ee6037b8cc5d04a71a4462f134801234567890abcdef1234567890abcdef1234567890abcdef1234567890abcdef1b"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{130,}$"
}
}
}Fields
signature: X402ExactEvmPermit2PayloadSignatureThe EIP-712 hex-encoded signature of the Permit2 PermitWitnessTransferFrom message. Smart account signatures may be longer than 65 bytes.
Implementations
Sourceimpl X402ExactEvmPermit2Payload
impl X402ExactEvmPermit2Payload
pub fn builder() -> X402ExactEvmPermit2Payload