pub struct X402ResourceQuality {
pub l30_days_total_calls: Option<i64>,
pub l30_days_unique_payers: Option<i64>,
pub last_called_at: Option<DateTime<Utc>>,
}Expand description
Quality metrics for a discovered x402 resource.
JSON schema
{
"description": "Quality metrics for a discovered x402 resource.",
"examples": [
{
"l30DaysTotalCalls": 42,
"l30DaysUniquePayers": 15,
"lastCalledAt": "2024-01-15T10:30:00Z"
}
],
"type": "object",
"properties": {
"l30DaysTotalCalls": {
"description": "Total number of paid calls to a resource in the last 30 days.",
"examples": [
42
],
"type": "integer"
},
"l30DaysUniquePayers": {
"description": "Number of unique payers to a resource in the last 30 days.",
"examples": [
15
],
"type": "integer"
},
"lastCalledAt": {
"description": "Timestamp of the most recent paid call to a resource.",
"examples": [
"2024-01-15T10:30:00Z"
],
"type": "string",
"format": "date-time"
}
}
}Fields
l30_days_total_calls: Option<i64>Total number of paid calls to a resource in the last 30 days.
l30_days_unique_payers: Option<i64>Number of unique payers to a resource in the last 30 days.
last_called_at: Option<DateTime<Utc>>Timestamp of the most recent paid call to a resource.
Implementations
Sourceimpl X402ResourceQuality
impl X402ResourceQuality
pub fn builder() -> X402ResourceQuality