pub struct X402VerifyPaymentRejection {
pub invalid_message: Option<String>,
pub invalid_reason: X402VerifyInvalidReason,
pub is_valid: bool,
pub payer: Option<X402VerifyPaymentRejectionPayer>,
}Expand description
The result when x402 payment verification fails.
JSON schema
{
"description": "The result when x402 payment verification fails.",
"examples": [
{
"invalidMessage": "Insufficient funds",
"invalidReason": "insufficient_funds",
"isValid": false,
"payer": "0x742d35Cc6634C0532925a3b844Bc454e4438f44e"
}
],
"type": "object",
"required": [
"invalidReason",
"isValid"
],
"properties": {
"invalidMessage": {
"description": "The message describing the invalid reason.",
"examples": [
"Insufficient funds"
],
"type": "string"
},
"invalidReason": {
"$ref": "#/components/schemas/x402VerifyInvalidReason"
},
"isValid": {
"description": "Indicates whether the payment is valid.",
"examples": [
false
],
"type": "boolean"
},
"payer": {
"description": "The onchain address of the client that is paying for the resource.\n\nFor EVM networks, the payer will be a 0x-prefixed, checksum EVM address.\n\nFor Solana-based networks, the payer will be a base58-encoded Solana address.",
"examples": [
"0x742d35Cc6634C0532925a3b844Bc454e4438f44e"
],
"type": "string",
"pattern": "^(0x[a-fA-F0-9]{40}|[1-9A-HJ-NP-Za-km-z]{32,44})$"
}
}
}Fields
invalid_message: Option<String>The message describing the invalid reason.
invalid_reason: X402VerifyInvalidReasonis_valid: boolIndicates whether the payment is valid.
payer: Option<X402VerifyPaymentRejectionPayer>The onchain address of the client that is paying for the resource.
For EVM networks, the payer will be a 0x-prefixed, checksum EVM address.
For Solana-based networks, the payer will be a base58-encoded Solana address.Implementations
Sourceimpl X402VerifyPaymentRejection
impl X402VerifyPaymentRejection
pub fn builder() -> X402VerifyPaymentRejection