pub enum ImportEndUserBodyKeyType {
Evm,
Solana,
}Expand description
The type of key being imported. Determines what type of account will be associated for the end user.
JSON schema
{
"description": "The type of key being imported. Determines what type of account will be associated for the end user.",
"examples": [
"evm"
],
"type": "string",
"enum": [
"evm",
"solana"
]
}Variants