pub enum PaymentMethodsPaymentMethod {
FedwirePaymentMethod(FedwirePaymentMethod),
SwiftPaymentMethod(SwiftPaymentMethod),
SepaPaymentMethod(SepaPaymentMethod),
}Expand description
A payment method linked to your entity. Payment methods represent external financial instruments that can be used as a target for transfers.
The `paymentRail` field indicates which type-specific details object is present. Type-specific fields are nested under a key matching the rail name (e.g., `fedwire`, `swift`).JSON schema
{
"description": "A payment method linked to your entity. Payment methods represent external financial instruments that can be used as a target for transfers.\n\nThe `paymentRail` field indicates which type-specific details object is present. Type-specific fields are nested under a key matching the rail name (e.g., `fedwire`, `swift`).",
"oneOf": [
{
"$ref": "#/components/schemas/FedwirePaymentMethod"
},
{
"$ref": "#/components/schemas/SwiftPaymentMethod"
},
{
"$ref": "#/components/schemas/SepaPaymentMethod"
}
]
}Variants
FedwirePaymentMethod(FedwirePaymentMethod)
SwiftPaymentMethod(SwiftPaymentMethod)
SepaPaymentMethod(SepaPaymentMethod)