pub enum TransferStatus {
Quoted,
Processing,
Completed,
Failed,
}Expand description
The current status of the transfer, indicating what action you need to take next. Required when validateOnly is false.
JSON schema
{
"description": "The current status of the transfer, indicating what action you need to take next. Required when validateOnly is false.",
"examples": [
"quoted"
],
"type": "string",
"enum": [
"quoted",
"processing",
"completed",
"failed"
],
"x-enum-descriptions": [
"Transfer was created with `execute: true`, but is momentarily being quoted before executing _or_ the transfer was created with `execute: false`. It can be executed by calling `/v2/transfers/{transferId}/execute` with `execute: true`.",
"Transfer is executing after being quoted. No action needed - monitor progress via the transfers webhook.",
"Transfer completed successfully.",
"Transfer failed. See `failureReason` for details."
]
}Variants