pub enum TravelRuleStatus {
Incomplete,
Completed,
}Expand description
The status of a travel rule submission.
JSON schema
{
"description": "The status of a travel rule submission.",
"examples": [
"incomplete"
],
"type": "string",
"enum": [
"incomplete",
"completed"
],
"x-enum-descriptions": [
"Additional fields are required before the transfer can proceed.",
"All requirements are satisfied and the transfer will proceed."
],
"x-enum-varnames": [
"TravelRuleStatusIncomplete",
"TravelRuleStatusCompleted"
]
}Variants