X402v2PaymentPayloadPayload

Enum X402v2PaymentPayloadPayload 

pub enum X402v2PaymentPayloadPayload {
    ExactEvmPayload(X402ExactEvmPayload),
    ExactEvmPermit2Payload(X402ExactEvmPermit2Payload),
    ExactSolanaPayload(X402ExactSolanaPayload),
    UptoEvmPermit2Payload(X402UptoEvmPermit2Payload),
    BatchSettlementEvmPayload(X402BatchSettlementEvmPayload),
}
The payload of the payment depending on the x402Version, scheme, and network. Discriminated by scheme-specific fields: exact-EVM/upto-EVM payloads carry a signature; exact-Solana carries a transaction; batch-settlement carries a type discriminator. See x402BatchSettlementEvmPayload for the documented batch-settlement variants.

JSON schema
{
 "description": "The payload of the payment depending on the x402Version, scheme, and network. Discriminated by scheme-specific fields: exact-EVM/upto-EVM payloads carry a `signature`; exact-Solana carries a `transaction`; batch-settlement carries a `type` discriminator. See `x402BatchSettlementEvmPayload` for the documented batch-settlement variants.",
 "examples": [
   {
     "authorization": {
       "from": "0x742d35Cc6634C0532925a3b844Bc454e4438f44e",
       "nonce": "0x1234567890abcdef1234567890abcdef1234567890abcdef1234567890abcdef",
       "to": "0x742d35Cc6634C0532925a3b844Bc454e4438f44e",
       "validAfter": "1716150000",
       "validBefore": "1716150000",
       "value": "1000000000000000000"
     },
     "signature": "0xf3746613c2d920b5fdabc0856f2aeb2d4f88ee6037b8cc5d04a71a4462f134801234567890abcdef1234567890abcdef1234567890abcdef1234567890abcdef1b"
   }
 ],
 "type": "object",
 "oneOf": [
   {
     "$ref": "#/components/schemas/x402ExactEvmPayload"
   },
   {
     "$ref": "#/components/schemas/x402ExactEvmPermit2Payload"
   },
   {
     "$ref": "#/components/schemas/x402ExactSolanaPayload"
   },
   {
     "$ref": "#/components/schemas/x402UptoEvmPermit2Payload"
   },
   {
     "$ref": "#/components/schemas/x402BatchSettlementEvmPayload"
   }
 ]
}

Variants



ExactEvmPayload(X402ExactEvmPayload)



ExactEvmPermit2Payload(X402ExactEvmPermit2Payload)



ExactSolanaPayload(X402ExactSolanaPayload)



UptoEvmPermit2Payload(X402UptoEvmPermit2Payload)



BatchSettlementEvmPayload(X402BatchSettlementEvmPayload)