pub struct AmountDetail {
pub available: String,
pub total: String,
}Expand description
Available and total amounts for a specific currency.
JSON schema
{
"description": "Available and total amounts for a specific currency.",
"type": "object",
"required": [
"available",
"total"
],
"properties": {
"available": {
"description": "The amount that is currently available to be used.",
"examples": [
"2.5"
],
"type": "string"
},
"total": {
"description": "The total amount, including the amount that is currently on hold.",
"examples": [
"3.0"
],
"type": "string"
}
}
}Fields
available: StringThe amount that is currently available to be used.
total: StringThe total amount, including the amount that is currently on hold.
Implementations
Sourceimpl AmountDetail
impl AmountDetail
pub fn builder() -> AmountDetail