pub struct CryptoDepositDestination {
pub account_id: AccountId,
pub created_at: DateTime<Utc>,
pub crypto: DepositDestinationCrypto,
pub deposit_destination_id: DepositDestinationId,
pub metadata: Option<Metadata>,
pub status: DepositDestinationStatus,
pub target: Option<DepositDestinationTarget>,
pub type_: CryptoDepositDestinationType,
pub updated_at: DateTime<Utc>,
}Expand description
A cryptocurrency deposit destination.
JSON schema
{
"description": "A cryptocurrency deposit destination.",
"examples": [
{
"accountId": "account_af2937b0-9846-4fe7-bfe9-ccc22d935114",
"createdAt": "2023-10-08T14:30:00Z",
"crypto": {
"address": "0x742d35Cc6634C0532925a3b844Bc454e4438f44e",
"network": "base"
},
"depositDestinationId": "depositDestination_af2937b0-9846-4fe7-bfe9-ccc22d935114",
"metadata": {
"customer_id": "123e4567-e89b-12d3-a456-426614174000",
"reference": "order-12345"
},
"status": "active",
"target": {
"accountId": "account_bf3847c1-a957-5ae8-cfa0-ddd33e046225",
"asset": "usd"
},
"type": "crypto",
"updatedAt": "2023-10-08T14:30:00Z"
}
],
"type": "object",
"required": [
"accountId",
"createdAt",
"crypto",
"depositDestinationId",
"status",
"type",
"updatedAt"
],
"properties": {
"accountId": {
"$ref": "#/components/schemas/AccountId"
},
"createdAt": {
"description": "The timestamp when the deposit destination was created.",
"examples": [
"2023-10-08T14:30:00Z"
],
"type": "string",
"format": "date-time"
},
"crypto": {
"description": "Crypto-specific details for this deposit destination. Always populated in responses. Contains the network and address.",
"allOf": [
{
"$ref": "#/components/schemas/DepositDestinationCrypto"
}
]
},
"depositDestinationId": {
"$ref": "#/components/schemas/DepositDestinationId"
},
"metadata": {
"$ref": "#/components/schemas/Metadata"
},
"status": {
"$ref": "#/components/schemas/DepositDestinationStatus"
},
"target": {
"$ref": "#/components/schemas/DepositDestinationTarget"
},
"type": {
"description": "The type of deposit destination.",
"examples": [
"crypto"
],
"type": "string",
"enum": [
"crypto"
]
},
"updatedAt": {
"description": "The timestamp when the deposit destination was last updated.",
"examples": [
"2023-10-08T14:30:00Z"
],
"type": "string",
"format": "date-time"
}
}
}Fields
account_id: AccountIdcreated_at: DateTime<Utc>The timestamp when the deposit destination was created.
crypto: DepositDestinationCryptoCrypto-specific details for this deposit destination. Always populated in responses. Contains the network and address.
deposit_destination_id: DepositDestinationIdmetadata: Option<Metadata>status: DepositDestinationStatustarget: Option<DepositDestinationTarget>type_: CryptoDepositDestinationTypeThe type of deposit destination.
updated_at: DateTime<Utc>The timestamp when the deposit destination was last updated.
Implementations
Sourceimpl CryptoDepositDestination
impl CryptoDepositDestination
pub fn builder() -> CryptoDepositDestination