pub struct DepositDestination(pub CryptoDepositDestination);Expand description
A deposit destination for receiving funds to an account.
JSON schema
{
"description": "A deposit destination for receiving funds to an account.",
"oneOf": [
{
"$ref": "#/components/schemas/CryptoDepositDestination"
}
]
}Tuple Fields
0: CryptoDepositDestinationTrait Implementations
Sourceimpl Clone for DepositDestination
impl Clone for DepositDestination
Sourcefn clone(&self) -> DepositDestination
fn clone(&self) -> DepositDestination
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DepositDestination
impl Debug for DepositDestination
Sourceimpl Deref for DepositDestination
impl Deref for DepositDestination
Sourcetype Target = CryptoDepositDestination
type Target = CryptoDepositDestination
The resulting type after dereferencing.
Sourcefn deref(&self) -> &CryptoDepositDestination
fn deref(&self) -> &CryptoDepositDestination
Dereferences the value.
Sourceimpl<'de> Deserialize<'de> for DepositDestination
impl<'de> Deserialize<'de> for DepositDestination
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&DepositDestination> for DepositDestination
impl From<&DepositDestination> for DepositDestination
Sourcefn from(value: &DepositDestination) -> Self
fn from(value: &DepositDestination) -> Self
Converts to this type from the input type.
Sourceimpl From<CryptoDepositDestination> for DepositDestination
impl From<CryptoDepositDestination> for DepositDestination
Sourcefn from(value: CryptoDepositDestination) -> Self
fn from(value: CryptoDepositDestination) -> Self
Converts to this type from the input type.
Sourceimpl From<DepositDestination> for CryptoDepositDestination
impl From<DepositDestination> for CryptoDepositDestination
Sourcefn from(value: DepositDestination) -> Self
fn from(value: DepositDestination) -> Self
Converts to this type from the input type.