pub struct DepositDestinationTargetAccount {
pub account_id: Option<AccountId>,
pub asset: Asset,
}Expand description
The account and asset where incoming deposits should be credited.
JSON schema
{
"title": "Target Account",
"description": "The account and asset where incoming deposits should be credited.",
"examples": [
{
"accountId": "account_af2937b0-9846-4fe7-bfe9-ccc22d935114",
"asset": "usd"
}
],
"type": "object",
"required": [
"asset"
],
"properties": {
"accountId": {
"description": "The ID of the CDP Account to which deposited funds should be transferred.",
"allOf": [
{
"$ref": "#/components/schemas/AccountId"
}
]
},
"asset": {
"description": "The symbol of the asset that should land in the target account.",
"examples": [
"usd"
],
"allOf": [
{
"$ref": "#/components/schemas/Asset"
}
]
}
},
"additionalProperties": false
}Fields
account_id: Option<AccountId>The ID of the CDP Account to which deposited funds should be transferred.
asset: AssetThe symbol of the asset that should land in the target account.
Implementations