pub struct ImportEndUserBody {
pub authentication_methods: AuthenticationMethods,
pub encrypted_private_key: String,
pub key_type: ImportEndUserBodyKeyType,
pub user_id: ImportEndUserBodyUserId,
}Expand description
ImportEndUserBody
JSON schema
{
"type": "object",
"required": [
"authenticationMethods",
"encryptedPrivateKey",
"keyType",
"userId"
],
"properties": {
"authenticationMethods": {
"$ref": "#/components/schemas/AuthenticationMethods"
},
"encryptedPrivateKey": {
"description": "The base64-encoded, encrypted private key to import. The private key must be encrypted using the CDP SDK's encryption scheme. This is a 32-byte raw private key.",
"examples": [
"U2FsdGVkX1+vupppZksvRf5X5YgHq4+da+Q4qf51+Q4="
],
"type": "string"
},
"keyType": {
"description": "The type of key being imported. Determines what type of account will be associated for the end user.",
"examples": [
"evm"
],
"type": "string",
"enum": [
"evm",
"solana"
]
},
"userId": {
"description": "A stable, unique identifier for the end user. The `userId` must be unique across all end users in the developer's CDP Project. It must be between 1 and 100 characters long and can only contain alphanumeric characters and hyphens.",
"examples": [
"e051beeb-7163-4527-a5b6-35e301529ff2"
],
"type": "string",
"pattern": "^[a-zA-Z0-9-]{1,100}$"
}
}
}Fields
authentication_methods: AuthenticationMethodsencrypted_private_key: StringThe base64-encoded, encrypted private key to import. The private key must be encrypted using the CDP SDK’s encryption scheme. This is a 32-byte raw private key.
key_type: ImportEndUserBodyKeyTypeThe type of key being imported. Determines what type of account will be associated for the end user.
user_id: ImportEndUserBodyUserIdA stable, unique identifier for the end user. The userId must be unique across all end users in the developer’s CDP Project. It must be between 1 and 100 characters long and can only contain alphanumeric characters and hyphens.
Implementations
Sourceimpl ImportEndUserBody
impl ImportEndUserBody
pub fn builder() -> ImportEndUserBody