pub struct OnchainDataColumnSchema {
pub description: Option<Description>,
pub index_order: Option<i64>,
pub name: Option<String>,
pub nullable: Option<bool>,
pub type_: Option<String>,
}Expand description
Schema definition for a table column.
JSON schema
{
"description": "Schema definition for a table column.",
"examples": [
{
"description": "The signature of the decoded event log.",
"indexOrder": 0,
"name": "event_signature",
"nullable": false,
"type": "String"
}
],
"type": "object",
"properties": {
"description": {
"description": "Human-readable description of the column.",
"examples": [
"The signature of the decoded event log."
],
"allOf": [
{
"$ref": "#/components/schemas/Description"
}
]
},
"indexOrder": {
"description": "The order of the column in the index. A lower number means the column is more important for the index and should be first in the query.",
"examples": [
0
],
"type": "integer"
},
"name": {
"description": "Column name.",
"examples": [
"event_signature"
],
"type": "string"
},
"nullable": {
"description": "Whether this column can contain NULL values.",
"examples": [
false
],
"type": "boolean"
},
"type": {
"description": "Column data type.",
"examples": [
"String"
],
"type": "string"
}
}
}Fields
description: Option<Description>Human-readable description of the column.
index_order: Option<i64>The order of the column in the index. A lower number means the column is more important for the index and should be first in the query.
name: Option<String>Column name.
nullable: Option<bool>Whether this column can contain NULL values.
type_: Option<String>Column data type.
Implementations
Sourceimpl OnchainDataColumnSchema
impl OnchainDataColumnSchema
pub fn builder() -> OnchainDataColumnSchema