pub struct RevokeDelegationForEndUserAccountBody {
pub wallet_secret_id: Option<RevokeDelegationForEndUserAccountBodyWalletSecretId>,
}Expand description
RevokeDelegationForEndUserAccountBody
JSON schema
{
"type": "object",
"properties": {
"walletSecretId": {
"description": "When revoking with a wallet authentication scheme, the ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.",
"examples": [
"e051beeb-7163-4527-a5b6-35e301529ff2"
],
"type": "string",
"pattern": "^[a-zA-Z0-9-]{1,100}$"
}
}
}Fields
wallet_secret_id: Option<RevokeDelegationForEndUserAccountBodyWalletSecretId>When revoking with a wallet authentication scheme, the ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.
Implementations