pub struct SendEndUserEvmAssetRule {
pub action: SendEndUserEvmAssetRuleAction,
pub criteria: SendEndUserEvmAssetCriteria,
pub operation: SendEndUserEvmAssetRuleOperation,
}Expand description
SendEndUserEvmAssetRule
JSON schema
{
"title": "SendEndUserEvmAssetRule",
"required": [
"action",
"criteria",
"operation"
],
"properties": {
"action": {
"description": "Whether matching the rule will cause the request to be rejected or accepted.",
"examples": [
"accept"
],
"type": "string",
"enum": [
"reject",
"accept"
]
},
"criteria": {
"$ref": "#/components/schemas/SendEndUserEvmAssetCriteria"
},
"operation": {
"description": "The operation to which the rule applies. Every element of the `criteria` array must match the specified operation.",
"examples": [
"sendEndUserEvmAsset"
],
"type": "string",
"enum": [
"sendEndUserEvmAsset"
]
}
},
"x-audience": "public"
}Fields
action: SendEndUserEvmAssetRuleActionWhether matching the rule will cause the request to be rejected or accepted.
criteria: SendEndUserEvmAssetCriteriaoperation: SendEndUserEvmAssetRuleOperationThe operation to which the rule applies. Every element of the criteria array must match the specified operation.
Implementations
Sourceimpl SendEndUserEvmAssetRule
impl SendEndUserEvmAssetRule
pub fn builder() -> SendEndUserEvmAssetRule