pub struct SendEndUserSolAssetRule {
pub action: SendEndUserSolAssetRuleAction,
pub criteria: SendEndUserSolAssetCriteria,
pub operation: SendEndUserSolAssetRuleOperation,
}Expand description
SendEndUserSolAssetRule
JSON schema
{
"title": "SendEndUserSolAssetRule",
"required": [
"action",
"criteria",
"operation"
],
"properties": {
"action": {
"description": "Whether matching the rule will cause the request to be rejected or accepted.",
"examples": [
"accept"
],
"type": "string",
"enum": [
"reject",
"accept"
]
},
"criteria": {
"$ref": "#/components/schemas/SendEndUserSolAssetCriteria"
},
"operation": {
"description": "The operation to which the rule applies. Every element of the `criteria` array must match the specified operation.",
"examples": [
"sendEndUserSolAsset"
],
"type": "string",
"enum": [
"sendEndUserSolAsset"
]
}
},
"x-audience": "public"
}Fields
action: SendEndUserSolAssetRuleActionWhether matching the rule will cause the request to be rejected or accepted.
criteria: SendEndUserSolAssetCriteriaoperation: SendEndUserSolAssetRuleOperationThe operation to which the rule applies. Every element of the criteria array must match the specified operation.
Implementations
Sourceimpl SendEndUserSolAssetRule
impl SendEndUserSolAssetRule
pub fn builder() -> SendEndUserSolAssetRule