pub struct SendEvmAssetWithEndUserAccountResponse {
pub transaction_hash: Option<String>,
pub user_op_hash: Option<String>,
}Expand description
SendEvmAssetWithEndUserAccountResponse
JSON schema
{
"type": "object",
"properties": {
"transactionHash": {
"description": "The hash of the transaction, as a 0x-prefixed hex string. Populated for EOA accounts. Null for Smart Accounts (use userOpHash instead).",
"examples": [
"0xf8f98fb6726fc936f24b2007df5cb20e2b8444ff3dfaa2a929335f432a9be2e7"
],
"type": [
"string",
"null"
]
},
"userOpHash": {
"description": "The hash of the user operation, as a 0x-prefixed hex string. Populated for Smart Accounts. Null for EOA accounts (use transactionHash instead).",
"examples": [
"0x1234567890abcdef1234567890abcdef1234567890abcdef1234567890abcdef"
],
"type": [
"string",
"null"
]
}
}
}Fields
transaction_hash: Option<String>The hash of the transaction, as a 0x-prefixed hex string. Populated for EOA accounts. Null for Smart Accounts (use userOpHash instead).
user_op_hash: Option<String>The hash of the user operation, as a 0x-prefixed hex string. Populated for Smart Accounts. Null for EOA accounts (use transactionHash instead).
Implementations