pub struct SendSolanaTransactionWithEndUserAccountBody {
pub address: SendSolanaTransactionWithEndUserAccountBodyAddress,
pub network: SendSolanaTransactionWithEndUserAccountBodyNetwork,
pub transaction: String,
pub use_cdp_sponsor: Option<bool>,
pub wallet_secret_id: Option<SendSolanaTransactionWithEndUserAccountBodyWalletSecretId>,
}Expand description
SendSolanaTransactionWithEndUserAccountBody
JSON schema
{
"type": "object",
"required": [
"address",
"network",
"transaction"
],
"properties": {
"address": {
"description": "The base58 encoded address of the Solana account belonging to the end user.",
"examples": [
"HpabPRRCFbBKSuJr5PdkVvQc85FyxyTWkFM2obBRSvHT"
],
"type": "string",
"pattern": "^[1-9A-HJ-NP-Za-km-z]{32,44}$"
},
"network": {
"description": "The Solana network to send the transaction to.",
"examples": [
"solana-devnet"
],
"type": "string",
"enum": [
"solana",
"solana-devnet"
]
},
"transaction": {
"description": "The base64 encoded transaction to sign and send. This transaction can contain multiple instructions for native Solana batching.",
"examples": [
"AQABAgIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAQABAQECAwQFBgcICQoLDA0ODxAREhMUFRYXGBkaGxwdHh8CBgMBAQAAAAIBAwQAAAAABgIAAAAAAAYDBQEBAAAGBAgAAAAABgUAAAAA6AMAAAAAAAAGBgUBAQEBBgcEAQAAAAYICgMBAQIDBgkCBgAAAAYKAwABAQEGCwMGAQEBBgwDAAABAQAAAAA="
],
"type": "string"
},
"useCdpSponsor": {
"description": "Whether transaction fees should be sponsored by CDP. When true, CDP sponsors the transaction fees on behalf of the end user. When false, the end user is responsible for paying the transaction fees.",
"examples": [
true
],
"type": "boolean"
},
"walletSecretId": {
"description": "Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.",
"examples": [
"e051beeb-7163-4527-a5b6-35e301529ff2"
],
"type": "string",
"pattern": "^[a-zA-Z0-9-]{1,100}$"
}
}
}Fields
address: SendSolanaTransactionWithEndUserAccountBodyAddressThe base58 encoded address of the Solana account belonging to the end user.
network: SendSolanaTransactionWithEndUserAccountBodyNetworkThe Solana network to send the transaction to.
transaction: StringThe base64 encoded transaction to sign and send. This transaction can contain multiple instructions for native Solana batching.
use_cdp_sponsor: Option<bool>Whether transaction fees should be sponsored by CDP. When true, CDP sponsors the transaction fees on behalf of the end user. When false, the end user is responsible for paying the transaction fees.
wallet_secret_id: Option<SendSolanaTransactionWithEndUserAccountBodyWalletSecretId>Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.
Implementations