pub struct SendUserOperationWithEndUserAccountBody {
pub calls: Vec<EvmCall>,
pub data_suffix: Option<SendUserOperationWithEndUserAccountBodyDataSuffix>,
pub network: EvmUserOperationNetwork,
pub paymaster_url: Option<Url>,
pub use_cdp_paymaster: bool,
pub wallet_secret_id: Option<SendUserOperationWithEndUserAccountBodyWalletSecretId>,
}Expand description
SendUserOperationWithEndUserAccountBody
JSON schema
{
"type": "object",
"required": [
"calls",
"network",
"useCdpPaymaster"
],
"properties": {
"calls": {
"description": "The list of calls to make from the Smart Account.",
"type": "array",
"items": {
"$ref": "#/components/schemas/EvmCall"
}
},
"dataSuffix": {
"description": "The EIP-8021 data suffix (hex-encoded) that enables transaction attribution for the user operation.",
"examples": [
"0xdddddddd62617365617070070080218021802180218021802180218021"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]+$"
},
"network": {
"$ref": "#/components/schemas/EvmUserOperationNetwork"
},
"paymasterUrl": {
"description": "The URL of the paymaster to use for the user operation. If using the CDP Paymaster, use the `useCdpPaymaster` option.",
"examples": [
"https://api.developer.coinbase.com/rpc/v1/base/<token>"
],
"allOf": [
{
"$ref": "#/components/schemas/Url"
}
]
},
"useCdpPaymaster": {
"description": "Whether to use the CDP Paymaster for the user operation.",
"examples": [
true
],
"type": "boolean"
},
"walletSecretId": {
"description": "Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.",
"examples": [
"e051beeb-7163-4527-a5b6-35e301529ff2"
],
"type": "string",
"pattern": "^[a-zA-Z0-9-]{1,100}$"
}
}
}Fields
calls: Vec<EvmCall>The list of calls to make from the Smart Account.
data_suffix: Option<SendUserOperationWithEndUserAccountBodyDataSuffix>The EIP-8021 data suffix (hex-encoded) that enables transaction attribution for the user operation.
network: EvmUserOperationNetworkpaymaster_url: Option<Url>The URL of the paymaster to use for the user operation. If using the CDP Paymaster, use the useCdpPaymaster option.
use_cdp_paymaster: boolWhether to use the CDP Paymaster for the user operation.
wallet_secret_id: Option<SendUserOperationWithEndUserAccountBodyWalletSecretId>Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.
Implementations