pub struct SignEndUserEvmHashRule {
pub action: SignEndUserEvmHashRuleAction,
pub operation: SignEndUserEvmHashRuleOperation,
}Expand description
SignEndUserEvmHashRule
JSON schema
{
"title": "SignEndUserEvmHashRule",
"required": [
"action",
"operation"
],
"properties": {
"action": {
"description": "Whether any attempts to sign a hash will be accepted or rejected. This rule does not accept any criteria.",
"examples": [
"accept"
],
"type": "string",
"enum": [
"reject",
"accept"
]
},
"operation": {
"description": "The operation to which the rule applies.",
"examples": [
"signEndUserEvmHash"
],
"type": "string",
"enum": [
"signEndUserEvmHash"
]
}
},
"x-audience": "public"
}Fields
action: SignEndUserEvmHashRuleActionWhether any attempts to sign a hash will be accepted or rejected. This rule does not accept any criteria.
operation: SignEndUserEvmHashRuleOperationThe operation to which the rule applies.
Implementations
Sourceimpl SignEndUserEvmHashRule
impl SignEndUserEvmHashRule
pub fn builder() -> SignEndUserEvmHashRule