pub struct SignEvmMessageWithEndUserAccountBody {
pub address: SignEvmMessageWithEndUserAccountBodyAddress,
pub message: String,
pub wallet_secret_id: Option<SignEvmMessageWithEndUserAccountBodyWalletSecretId>,
}Expand description
SignEvmMessageWithEndUserAccountBody
JSON schema
{
"type": "object",
"required": [
"address",
"message"
],
"properties": {
"address": {
"description": "The 0x-prefixed address of the EVM account belonging to the end user.",
"examples": [
"0x742d35Cc6634C0532925a3b844Bc454e4438f44e"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{40}$"
},
"message": {
"description": "The message to sign.",
"examples": [
"Hello, world!"
],
"type": "string"
},
"walletSecretId": {
"description": "Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.",
"examples": [
"e051beeb-7163-4527-a5b6-35e301529ff2"
],
"type": "string",
"pattern": "^[a-zA-Z0-9-]{1,100}$"
}
}
}Fields
address: SignEvmMessageWithEndUserAccountBodyAddressThe 0x-prefixed address of the EVM account belonging to the end user.
message: StringThe message to sign.
wallet_secret_id: Option<SignEvmMessageWithEndUserAccountBodyWalletSecretId>Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.
Implementations