pub struct SignEvmTransactionWithEndUserAccountBody {
pub address: SignEvmTransactionWithEndUserAccountBodyAddress,
pub transaction: String,
pub wallet_secret_id: Option<SignEvmTransactionWithEndUserAccountBodyWalletSecretId>,
}Expand description
SignEvmTransactionWithEndUserAccountBody
JSON schema
{
"type": "object",
"required": [
"address",
"transaction"
],
"properties": {
"address": {
"description": "The 0x-prefixed address of the EVM account belonging to the end user.",
"examples": [
"0x742d35Cc6634C0532925a3b844Bc454e4438f44e"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{40}$"
},
"transaction": {
"description": "The RLP-encoded transaction to sign, as a 0x-prefixed hex string.",
"examples": [
"0xf86b098505d21dba00830334509431415daf58e2c6b7323b4c58712fd92952145da79018080"
],
"type": "string"
},
"walletSecretId": {
"description": "Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.",
"examples": [
"e051beeb-7163-4527-a5b6-35e301529ff2"
],
"type": "string",
"pattern": "^[a-zA-Z0-9-]{1,100}$"
}
}
}Fields
address: SignEvmTransactionWithEndUserAccountBodyAddressThe 0x-prefixed address of the EVM account belonging to the end user.
transaction: StringThe RLP-encoded transaction to sign, as a 0x-prefixed hex string.
wallet_secret_id: Option<SignEvmTransactionWithEndUserAccountBodyWalletSecretId>Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.
Implementations