pub struct SignSolanaMessageWithEndUserAccountBody {
pub address: SignSolanaMessageWithEndUserAccountBodyAddress,
pub message: String,
pub wallet_secret_id: Option<SignSolanaMessageWithEndUserAccountBodyWalletSecretId>,
}Expand description
SignSolanaMessageWithEndUserAccountBody
JSON schema
{
"type": "object",
"required": [
"address",
"message"
],
"properties": {
"address": {
"description": "The base58 encoded address of the Solana account belonging to the end user.",
"examples": [
"HpabPRRCFbBKSuJr5PdkVvQc85FyxyTWkFM2obBRSvHT"
],
"type": "string",
"pattern": "^[1-9A-HJ-NP-Za-km-z]{32,44}$"
},
"message": {
"description": "The base64 encoded arbitrary message to sign.",
"examples": [
"SGVsbG8sIHdvcmxk"
],
"type": "string"
},
"walletSecretId": {
"description": "Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.",
"examples": [
"e051beeb-7163-4527-a5b6-35e301529ff2"
],
"type": "string",
"pattern": "^[a-zA-Z0-9-]{1,100}$"
}
}
}Fields
address: SignSolanaMessageWithEndUserAccountBodyAddressThe base58 encoded address of the Solana account belonging to the end user.
message: StringThe base64 encoded arbitrary message to sign.
wallet_secret_id: Option<SignSolanaMessageWithEndUserAccountBodyWalletSecretId>Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.
Implementations