pub struct SiweAuthentication {
pub address: BlockchainAddress,
pub type_: SiweAuthenticationType,
}Expand description
Information about an end user who authenticates using Sign In With Ethereum (EIP-4361).
JSON schema
{
"title": "SiweAuthentication",
"description": "Information about an end user who authenticates using Sign In With Ethereum (EIP-4361).",
"type": "object",
"required": [
"address",
"type"
],
"properties": {
"address": {
"description": "The ERC-55 checksummed Ethereum address of the end user.",
"examples": [
"0x742d35Cc6634C0532925a3b844Bc454e4438f44e"
],
"allOf": [
{
"$ref": "#/components/schemas/BlockchainAddress"
}
]
},
"type": {
"description": "The type of authentication information.",
"examples": [
"siwe"
],
"type": "string",
"enum": [
"siwe"
]
}
}
}Fields
address: BlockchainAddressThe ERC-55 checksummed Ethereum address of the end user.
type_: SiweAuthenticationTypeThe type of authentication information.
Implementations
Sourceimpl SiweAuthentication
impl SiweAuthentication
pub fn builder() -> SiweAuthentication