TransferDetailsTravelRule

Struct TransferDetailsTravelRule 

pub struct TransferDetailsTravelRule {
    pub status: Option<TravelRuleStatus>,
    pub status_message: Option<String>,
}
Travel rule compliance status for deposit transfers. Present when the transfer requires travel rule information.

JSON schema
{
 "description": "Travel rule compliance status for deposit transfers. Present when the transfer requires travel rule information.",
 "examples": [
   {
     "status": "incomplete",
     "statusMessage": "Originator date of birth is required."
   }
 ],
 "type": "object",
 "properties": {
   "status": {
     "$ref": "#/components/schemas/TravelRuleStatus"
   },
   "statusMessage": {
     "description": "Additional details about the current travel rule status. For example, when status is `incomplete`, this may indicate the specific missing information required to proceed.",
     "examples": [
       "Originator date of birth is required."
     ],
     "type": "string"
   }
 }
}

Fields

status: Option<TravelRuleStatus>status_message: Option<String>

Additional details about the current travel rule status. For example, when status is incomplete, this may indicate the specific missing information required to proceed.

Implementations