pub struct TravelRuleOriginator {
pub address: Option<PhysicalAddress>,
pub financial_institution: Option<String>,
pub name: Option<String>,
pub virtual_asset_service_provider: Option<TravelRuleOriginatorVirtualAssetServiceProvider>,
}Expand description
Originator (sender) party.
JSON schema
{
"description": "Originator (sender) party.",
"allOf": [
{
"$ref": "#/components/schemas/TravelRuleParty"
},
{
"type": "object",
"properties": {
"virtualAssetServiceProvider": {
"description": "Information about the originating Virtual Asset Service Provider (VASP) that handles cryptocurrency or other virtual assets on behalf of customers.",
"type": "object",
"properties": {
"address": {
"$ref": "#/components/schemas/PhysicalAddress"
},
"identifier": {
"description": "The Legal Entity Identifier of the originating Virtual Asset Service Provider (VASP).",
"examples": [
"5493001KJTIIGC8Y1R17"
],
"type": "string"
},
"name": {
"description": "The name of the originating Virtual Asset Service Provider (VASP).",
"examples": [
"Fidelity Digital Asset Services, LLC"
],
"type": "string"
}
}
}
}
}
]
}Fields
address: Option<PhysicalAddress>financial_institution: Option<String>Name of the financial institution.
name: Option<String>Full name of the party.
virtual_asset_service_provider: Option<TravelRuleOriginatorVirtualAssetServiceProvider>Implementations
Sourceimpl TravelRuleOriginator
impl TravelRuleOriginator
pub fn builder() -> TravelRuleOriginator