pub struct WebhookSubscriptionUpdateRequest {
pub description: Option<Description>,
pub event_types: Vec<String>,
pub is_enabled: bool,
pub labels: HashMap<String, String>,
pub metadata: Option<Metadata>,
pub target: WebhookTarget,
}Expand description
Request to update an existing webhook subscription.
JSON schema
{
"description": "Request to update an existing webhook subscription.\n",
"type": "object",
"required": [
"eventTypes",
"isEnabled",
"target"
],
"properties": {
"description": {
"description": "Description of the webhook subscription.",
"examples": [
"Updated subscription for token transfer events"
],
"allOf": [
{
"$ref": "#/components/schemas/Description"
}
]
},
"eventTypes": {
"description": "Types of events to subscribe to. Event types follow a three-part dot-separated format:\nservice.resource.verb (e.g., \"onchain.activity.detected\", \"wallet.activity.detected\", \"onramp.transaction.created\").\n",
"examples": [
[
"onchain.activity.detected"
]
],
"type": "array",
"items": {
"type": "string"
}
},
"isEnabled": {
"description": "Whether the subscription is enabled.",
"examples": [
false
],
"type": "boolean"
},
"labels": {
"description": "Optional. Multi-label filters that trigger only when an event contains ALL of these key-value pairs.\n\n**Note:** Currently, labels are supported for onchain webhooks only.\n\nSee [allowed labels for onchain webhooks](https://docs.cdp.coinbase.com/api-reference/v2/rest-api/webhooks/create-webhook-subscription#onchain-label-filtering).\nOmit to receive all events for the selected event types.\n",
"examples": [
{
"contract_address": "0x833589fcd6edb6e08f4c7c32d4f71b54bda02913",
"event_name": "Transfer",
"network": "base-mainnet"
}
],
"type": "object",
"additionalProperties": {
"type": "string"
}
},
"metadata": {
"$ref": "#/components/schemas/Metadata"
},
"target": {
"$ref": "#/components/schemas/WebhookTarget"
}
}
}Fields
description: Option<Description>Description of the webhook subscription.
event_types: Vec<String>Types of events to subscribe to. Event types follow a three-part dot-separated format: service.resource.verb (e.g., “onchain.activity.detected”, “wallet.activity.detected”, “onramp.transaction.created”).
is_enabled: boolWhether the subscription is enabled.
labels: HashMap<String, String>Optional. Multi-label filters that trigger only when an event contains ALL of these key-value pairs.
**Note:** Currently, labels are supported for onchain webhooks only.
See [allowed labels for onchain webhooks](https://docs.cdp.coinbase.com/api-reference/v2/rest-api/webhooks/create-webhook-subscription#onchain-label-filtering).
Omit to receive all events for the selected event types.metadata: Option<Metadata>target: WebhookTargetImplementations