X402ExactEvmPermit2PayloadPermit2Authorization

Struct X402ExactEvmPermit2PayloadPermit2Authorization 

pub struct X402ExactEvmPermit2PayloadPermit2Authorization {
    pub deadline: String,
    pub from: X402ExactEvmPermit2PayloadPermit2AuthorizationFrom,
    pub nonce: X402ExactEvmPermit2PayloadPermit2AuthorizationNonce,
    pub permitted: X402ExactEvmPermit2PayloadPermit2AuthorizationPermitted,
    pub spender: X402ExactEvmPermit2PayloadPermit2AuthorizationSpender,
    pub witness: X402ExactEvmPermit2PayloadPermit2AuthorizationWitness,
}
The authorization data for the Permit2 PermitWitnessTransferFrom message.

JSON schema
{
 "description": "The authorization data for the Permit2 PermitWitnessTransferFrom message.",
 "examples": [
   {
     "deadline": "1716150000",
     "from": "0x742d35Cc6634C0532925a3b844Bc454e4438f44e",
     "nonce": "12345678901234567890",
     "permitted": {
       "amount": "1000000",
       "token": "0x036CbD53842c5426634e7929541eC2318f3dCF7e"
     },
     "spender": "0x4020615294c913F045dc10f0a5cdEbd86c280001",
     "witness": {
       "extra": "0x",
       "to": "0x742d35Cc6634C0532925a3b844Bc454e4438f44e",
       "validAfter": "1716150000"
     }
   }
 ],
 "type": "object",
 "required": [
   "deadline",
   "from",
   "nonce",
   "permitted",
   "spender",
   "witness"
 ],
 "properties": {
   "deadline": {
     "description": "The unix timestamp before which the permit is valid.",
     "examples": [
       "1716150000"
     ],
     "type": "string"
   },
   "from": {
     "description": "The 0x-prefixed, checksum EVM address of the sender of the payment.",
     "examples": [
       "0x742d35Cc6634C0532925a3b844Bc454e4438f44e"
     ],
     "type": "string",
     "pattern": "^0x[0-9a-fA-F]{40}$"
   },
   "nonce": {
     "description": "The Permit2 nonce as a decimal string (uint256).",
     "examples": [
       "12345678901234567890"
     ],
     "type": "string",
     "pattern": "^[0-9]+$"
   },
   "permitted": {
     "description": "The token permissions for the transfer.",
     "type": "object",
     "required": [
       "amount",
       "token"
     ],
     "properties": {
       "amount": {
         "description": "The amount to transfer in atomic units.",
         "examples": [
           "1000000"
         ],
         "type": "string"
       },
       "token": {
         "description": "The 0x-prefixed, checksum EVM address of the token to transfer.",
         "examples": [
           "0x036CbD53842c5426634e7929541eC2318f3dCF7e"
         ],
         "type": "string",
         "pattern": "^0x[0-9a-fA-F]{40}$"
       }
     }
   },
   "spender": {
     "description": "The 0x-prefixed, checksum EVM address of the spender (x402 Permit2 proxy contract).",
     "examples": [
       "0x4020615294c913F045dc10f0a5cdEbd86c280001"
     ],
     "type": "string",
     "pattern": "^0x[0-9a-fA-F]{40}$"
   },
   "witness": {
     "description": "The witness data containing payment details.",
     "type": "object",
     "required": [
       "to",
       "validAfter"
     ],
     "properties": {
       "extra": {
         "description": "Optional hex-encoded extra data.",
         "examples": [
           "0x"
         ],
         "type": "string",
         "pattern": "^0x[0-9a-fA-F]*$"
       },
       "to": {
         "description": "The 0x-prefixed, checksum EVM address of the recipient.",
         "examples": [
           "0x742d35Cc6634C0532925a3b844Bc454e4438f44e"
         ],
         "type": "string",
         "pattern": "^0x[0-9a-fA-F]{40}$"
       },
       "validAfter": {
         "description": "The unix timestamp after which the payment is valid.",
         "examples": [
           "1716150000"
         ],
         "type": "string"
       }
     }
   }
 }
}

Fields

deadline: String

The unix timestamp before which the permit is valid.

from: X402ExactEvmPermit2PayloadPermit2AuthorizationFrom

The 0x-prefixed, checksum EVM address of the sender of the payment.

nonce: X402ExactEvmPermit2PayloadPermit2AuthorizationNonce

The Permit2 nonce as a decimal string (uint256).

permitted: X402ExactEvmPermit2PayloadPermit2AuthorizationPermittedspender: X402ExactEvmPermit2PayloadPermit2AuthorizationSpender

The 0x-prefixed, checksum EVM address of the spender (x402 Permit2 proxy contract).

witness: X402ExactEvmPermit2PayloadPermit2AuthorizationWitness

Implementations