pub struct X402BatchSettlementChannelConfig {
pub payer: X402BatchSettlementChannelConfigPayer,
pub payer_authorizer: X402BatchSettlementChannelConfigPayerAuthorizer,
pub receiver: X402BatchSettlementChannelConfigReceiver,
pub receiver_authorizer: X402BatchSettlementChannelConfigReceiverAuthorizer,
pub salt: X402BatchSettlementChannelConfigSalt,
pub token: X402BatchSettlementChannelConfigToken,
pub withdraw_delay: i64,
}Expand description
Immutable configuration for an x402 batch-settlement payment channel. The EIP-712 hash of this struct produces the channelId used by all batch-settlement payloads.
JSON schema
{
"title": "x402BatchSettlementChannelConfig",
"description": "Immutable configuration for an x402 batch-settlement payment channel. The EIP-712 hash of this struct produces the `channelId` used by all batch-settlement payloads.",
"examples": [
{
"payer": "0x857b06519E91e3A54538791bDbb0E22373e36b66",
"payerAuthorizer": "0x857b06519E91e3A54538791bDbb0E22373e36b66",
"receiver": "0x209693Bc6afc0C5328bA36FaF03C514EF312287C",
"receiverAuthorizer": "0x1111111111111111111111111111111111111111",
"salt": "0x0000000000000000000000000000000000000000000000000000000000000001",
"token": "0x036CbD53842c5426634e7929541eC2318f3dCF7e",
"withdrawDelay": 86400
}
],
"type": "object",
"required": [
"payer",
"payerAuthorizer",
"receiver",
"receiverAuthorizer",
"salt",
"token",
"withdrawDelay"
],
"properties": {
"payer": {
"description": "The 0x-prefixed, checksum EVM address of the payer (channel funder).",
"examples": [
"0x857b06519E91e3A54538791bDbb0E22373e36b66"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{40}$"
},
"payerAuthorizer": {
"description": "The 0x-prefixed, checksum EVM address authorized to sign vouchers on behalf of the payer.",
"examples": [
"0x857b06519E91e3A54538791bDbb0E22373e36b66"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{40}$"
},
"receiver": {
"description": "The 0x-prefixed, checksum EVM address of the receiver (resource server / merchant).",
"examples": [
"0x209693Bc6afc0C5328bA36FaF03C514EF312287C"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{40}$"
},
"receiverAuthorizer": {
"description": "The 0x-prefixed, checksum EVM address authorized to sign claim batches on behalf of the receiver (typically the facilitator).",
"examples": [
"0x1111111111111111111111111111111111111111"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{40}$"
},
"salt": {
"description": "A 32-byte salt used to differentiate channels between the same payer/receiver pair.",
"examples": [
"0x0000000000000000000000000000000000000000000000000000000000000001"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{64}$"
},
"token": {
"description": "The 0x-prefixed, checksum EVM address of the ERC-20 payment token.",
"examples": [
"0x036CbD53842c5426634e7929541eC2318f3dCF7e"
],
"type": "string",
"pattern": "^0x[0-9a-fA-F]{40}$"
},
"withdrawDelay": {
"description": "The non-cooperative withdraw delay in seconds. Must be between 900 (15 minutes) and 2,592,000 (30 days).",
"examples": [
86400
],
"type": "integer",
"maximum": 2592000.0,
"minimum": 900.0
}
}
}Fields
payer: X402BatchSettlementChannelConfigPayerThe 0x-prefixed, checksum EVM address of the payer (channel funder).
The 0x-prefixed, checksum EVM address authorized to sign vouchers on behalf of the payer.
receiver: X402BatchSettlementChannelConfigReceiverThe 0x-prefixed, checksum EVM address of the receiver (resource server / merchant).
The 0x-prefixed, checksum EVM address authorized to sign claim batches on behalf of the receiver (typically the facilitator).
salt: X402BatchSettlementChannelConfigSaltA 32-byte salt used to differentiate channels between the same payer/receiver pair.
token: X402BatchSettlementChannelConfigTokenThe 0x-prefixed, checksum EVM address of the ERC-20 payment token.
withdraw_delay: i64The non-cooperative withdraw delay in seconds. Must be between 900 (15 minutes) and 2,592,000 (30 days).
Implementations