SendSolanaAssetWithEndUserAccountBody

Struct SendSolanaAssetWithEndUserAccountBody 

pub struct SendSolanaAssetWithEndUserAccountBody {
    pub amount: SendSolanaAssetWithEndUserAccountBodyAmount,
    pub create_recipient_ata: Option<bool>,
    pub network: SendSolanaAssetWithEndUserAccountBodyNetwork,
    pub to: BlockchainAddress,
    pub use_cdp_sponsor: Option<bool>,
    pub wallet_secret_id: Option<SendSolanaAssetWithEndUserAccountBodyWalletSecretId>,
}
SendSolanaAssetWithEndUserAccountBody

JSON schema
{
 "type": "object",
 "required": [
   "amount",
   "network",
   "to"
 ],
 "properties": {
   "amount": {
     "description": "The amount of USDC to send as a decimal string (e.g., \"1.5\" or \"25.50\").",
     "examples": [
       "1.50"
     ],
     "type": "string",
     "maxLength": 32,
     "minLength": 1
   },
   "createRecipientAta": {
     "description": "Whether to automatically create an Associated Token Account (ATA) for the recipient if it doesn't exist. When true, the sender pays the rent-exempt minimum to create the recipient's USDC ATA. When false, the transaction will fail if the recipient doesn't have a USDC ATA.",
     "examples": [
       true
     ],
     "type": "boolean"
   },
   "network": {
     "description": "The Solana network to send USDC on.",
     "examples": [
       "solana-devnet"
     ],
     "type": "string",
     "enum": [
       "solana",
       "solana-devnet"
     ]
   },
   "to": {
     "$ref": "#/components/schemas/BlockchainAddress"
   },
   "useCdpSponsor": {
     "description": "Whether transaction fees should be sponsored by CDP. When true, CDP sponsors the transaction fees on behalf of the end user. When false, the end user is responsible for paying the transaction fees.",
     "examples": [
       true
     ],
     "type": "boolean"
   },
   "walletSecretId": {
     "description": "Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.",
     "examples": [
       "e051beeb-7163-4527-a5b6-35e301529ff2"
     ],
     "type": "string",
     "pattern": "^[a-zA-Z0-9-]{1,100}$"
   }
 }
}

Fields

amount: SendSolanaAssetWithEndUserAccountBodyAmount

The amount of USDC to send as a decimal string (e.g., “1.5” or “25.50”).

create_recipient_ata: Option<bool>

Whether to automatically create an Associated Token Account (ATA) for the recipient if it doesn’t exist. When true, the sender pays the rent-exempt minimum to create the recipient’s USDC ATA. When false, the transaction will fail if the recipient doesn’t have a USDC ATA.

network: SendSolanaAssetWithEndUserAccountBodyNetwork

The Solana network to send USDC on.

to: BlockchainAddressuse_cdp_sponsor: Option<bool>

Whether transaction fees should be sponsored by CDP. When true, CDP sponsors the transaction fees on behalf of the end user. When false, the end user is responsible for paying the transaction fees.

wallet_secret_id: Option<SendSolanaAssetWithEndUserAccountBodyWalletSecretId>

Required when not using delegated signing. The ID of the Temporary Wallet Secret that was used to sign the X-Wallet-Auth Header.

Implementations